@@ -2,7 +2,7 @@
 function (gen) 
 {
     if (!exists("genotypesNames")) {
-        data(genotypesNames, package = "noia")
+        genotypesNames <- NULL; rm(genotypesNames); data(genotypesNames, package = "noia")
     }
     ans <- NULL
     n.gen <- apply(!is.na(gen), 2, "sum")
